@@ -10,15 +10,6 @@ use Giovanni::Stages;
 
 extends 'Giovanni::Stages';
 
-=head1 NAME
-
-Giovanni - a Perl based deployment system
-
-=head1 VERSION
-
-Version 1.8.7.7.4.4.5.5.4.4
-
-=cut
 
 our $VERSION = '1.8';
 
@@ -83,26 +74,6 @@ has 'notifyer' => (
     default => 'jabber',
 );
 
-=head1 SYNOPSIS
-
-Giovanni is a Perl replacement for the idea behind Capistrano. It is a
-deployment system that can be used comfortably from the commandline to
-check out code, restart systems and notify.
-The system is currently used with git and manages some Catalyst and
-Mojolicious apps and notifies via Jabber. It supports timestamped
-rollouts (ie have the last 5 versions of your code on the server and link
-to the currently running one) and plain git repositories. It tries to
-detect problems in the deployment process and rolls back. It supports
-manual rollbacks, two restart modes and does all that without any code
-on the server. All you need is a working ssh setup with ssh-keys that
-handle the login. 
-We also use it with Jenkins to automatically deploy
-code that successfully completed the test suite.
-
-Giovanni comes with a commandline tool called gio. Check the gio manpage
-for the config file format.
-
-=cut
 
 sub deploy {
     my ($self) = @_;
@@ -218,6 +189,50 @@ sub notify {
     return;
 }
 
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Giovanni
+
+=head1 VERSION
+
+version 0.9
+
+=head1 SYNOPSIS
+
+Giovanni is a Perl replacement for the idea behind Capistrano. It is a
+deployment system that can be used comfortably from the commandline to
+check out code, restart systems and notify.
+The system is currently used with git and manages some Catalyst and
+Mojolicious apps and notifies via Jabber. It supports timestamped
+rollouts (ie have the last 5 versions of your code on the server and link
+to the currently running one) and plain git repositories. It tries to
+detect problems in the deployment process and rolls back. It supports
+manual rollbacks, two restart modes and does all that without any code
+on the server. All you need is a working ssh setup with ssh-keys that
+handle the login. 
+We also use it with Jenkins to automatically deploy
+code that successfully completed the test suite.
+
+Giovanni comes with a commandline tool called gio. Check the gio manpage
+for the config file format.
+
+=head1 NAME
+
+Giovanni - a Perl based deployment system
+
+=head1 VERSION
+
+Version 1.8.7.7.4.4.5.5.4.4
+
 =head1 AUTHOR
 
 Lenz Gschwendtner, C<< <norbu09 at cpan.org> >>
@@ -228,16 +243,12 @@ Please report any bugs or feature requests to C<bug-giovanni at rt.cpan.org>, or
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Giovanni>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
-
-
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
     perldoc Giovanni
 
-
 You can also look for information at:
 
 =over 4
@@ -260,10 +271,8 @@ L<http://search.cpan.org/dist/Giovanni/>
 
 =back
 
-
 =head1 ACKNOWLEDGEMENTS
 
-
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2011 Lenz Gschwendtner.
@@ -274,7 +283,15 @@ by the Free Software Foundation; or the Artistic License.
 
 See http://dev.perl.org/licenses/ for more information.
 
+=head1 AUTHOR
+
+Lenz Gschwendtner <mail@norbu09.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by ideegeo Group Limited.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
